@@ -480,7 +480,7 @@ class objearth():
             )
         }
         nc5 = colors.LinearSegmentedColormap('new_cmap',segmentdata=cdict)
-        nc5
+        return nc5
 
 
 
@@ -1102,8 +1102,9 @@ class water:
 
             # plotshow Result
             rgb = np.stack([red,green,blue],axis=2)
-            plt.figure(figsize=(8,8))
-            plt.axis('off')
-            plt.imshow(rgb)
+            objearth.plotshow(rgb)
+            # plt.figure(figsize=(8,8))
+            # plt.axis('off')
+            # plt.imshow(rgb)
             
             return red*10000,green*10000,blue*10000
